#!/usr/bin/env python

import socket, sys, time, traceback
import libasyncns

if __name__ == '__main__':
	
	if '-h' in sys.argv[1:]:
		print('{0} [-e] [-h]'.format(sys.argv[0]))
		print('  -e: add invalid addresses to trigger errors')
		print('  -h: display this help')
		sys.exit(0)
	
	urls = [
	        'www.kame.net',
	        'www.ipv6.org',
	        'localhost',
	       ]
	
	if '-e' in sys.argv[1:]:
		urls.append('a.com')       # can't be resolved (reserved)
		urls.append('www.invalid') # can't be resolved (invalid TLD)
		urls.append('\x10')        # can't be resolved (invalid)
	
	print('socket.getaddrinfo(...):')
	t = time.time()
	for url in urls:
		try:
			for ip in socket.getaddrinfo(url, None):
				print('  {0}: {1}'.format(url, ip))
		except:
			print('Exception for "{0}":'.format(url))
			traceback.print_exc()
	print('{0} seconds'.format(time.time() - t))
	print('')
	
	print('asyncns.getaddrinfo(...):')
	t = time.time()
	asyncns = libasyncns.Asyncns()
	for url in urls:
		q = asyncns.getaddrinfo(url, None)
		q.userdata = url
	
	while asyncns.get_nqueries() > 0:
		asyncns.wait(True)
		q = True
		while q:
			try: q = asyncns.get_next()
			except: q = None
			if q and q.is_done():
				try:
					for ip in q.get_done():
						print('  {0}: {1}'.format(q.userdata, ip))
				except:
					print('Exception for "{0}":'.format(q.userdata))
					traceback.print_exc()
	print('{0} seconds'.format(time.time() - t))
	print('')
	
